@@ -2,32 +2,30 @@
 #' 
 #' Compute the heldout log-likelihood of the STS model
 #' 
-#' @param mv the baseline log-transformed occurrence rate of each word in the 
-#' corpus
-#' @param kappa the estimated kappa coefficients
-#' @param alpha the estimated alpha values for the corpus
+#' @param object an sts object, typically after applying \code{\link[stm]{make.heldout}}
 #' @param missing list of which words and documents are in the heldout set
 #' 
 #' @return expected.heldout is the average of the held-out log-likelihood values 
 #' for each document.
 #' 
-#' @examples 
+#' @examples \donttest{
 #' library("tm"); library("stm"); library("sts")
 #' temp<-textProcessor(documents=gadarian$open.ended.response,
 #' metadata=gadarian, verbose = FALSE)
 #' out <- prepDocuments(temp$documents, temp$vocab, temp$meta, verbose = FALSE)
 #' out$meta$noTreatment <- ifelse(out$meta$treatment == 1, -1, 1)
 #' out_ho <- make.heldout(out$documents, out$vocab)
+#' out_ho$meta <- out$meta
 #' ## low max iteration number just for testing
-#' sts_estimate <- sts(~ treatment*pid_rep, ~ noTreatment, out, K = 3, maxIter = 2)
-#' sm <- sample(x=1:length(out_ho$missing$index), 
-#' size = length(out_ho$missing$index)*0.8, replace = TRUE)
-#' d.h <- list(index = out_ho$missing$index[sm], docs = out_ho$missing$docs[sm])
-#' heldoutLikelihood(mv=sts_estimate$mv, kappa=sts_estimate$kappa, 
-#' alpha=sts_estimate$alpha, missing=d.h)$expected.heldout
+#' sts_estimate <- sts(~ treatment*pid_rep, ~ noTreatment, out_ho, K = 3, maxIter = 2, verbose = FALSE)
+#' heldoutLikelihood(sts_estimate, out_ho$missing)$expected.heldout
+#' }
 #' @export
-heldoutLikelihood <- function (mv, kappa, alpha, missing) 
+heldoutLikelihood <- function (object, missing) 
 {
+  mv <- object$mv
+  kappa <- object$kappa
+  alpha <- object$alpha
   K <- (1 + ncol(alpha))/2
   
   heldout <- vector(length = length(missing$index))
